@@ -5,7 +5,7 @@
  * Compile this file with -DNO_DEFLATE to avoid the compression code.
  */
 
-/* @(#) $Id: gzio.c,v 1.1.1.1 1999/04/05 22:14:11 curt Exp $ */
+/* @(#) $Id: gzio.c,v 1.1 1998/04/18 03:48:37 curt Exp $ */
 
 #include <stdio.h>
 
@@ -414,14 +414,10 @@ int ZEXPORT gzread (file, buf, len)
 	    s->crc = crc32(s->crc, start, (uInt)(s->stream.next_out - start));
 	    start = s->stream.next_out;
 
-	    if (getLong(s) != s->crc) {
+	    if (getLong(s) != s->crc || getLong(s) != s->stream.total_out) {
 		s->z_err = Z_DATA_ERROR;
 	    } else {
-	        (void)getLong(s);
-                /* The uncompressed length returned by above getlong() may
-                 * be different from s->stream.total_out) in case of
-		 * concatenated .gz files. Check for such files:
-		 */
+		/* Check for concatenated .gz files: */
 		check_header(s);
 		if (s->z_err == Z_OK) {
 		    uLong total_in = s->stream.total_in;
@@ -674,7 +670,7 @@ z_off_t ZEXPORT gzseek (file, offset, whence)
 	return -1L;
 #else
 	if (whence == SEEK_SET) {
-	    offset -= s->stream.total_in;
+	    offset -= s->stream.total_out;
 	}
 	if (offset < 0) return -1L;
 
@@ -749,7 +745,6 @@ int ZEXPORT gzrewind (file)
     s->z_eof = 0;
     s->stream.avail_in = 0;
     s->stream.next_in = s->inbuf;
-    s->crc = crc32(0L, Z_NULL, 0);
 	
     if (s->startpos == 0) { /* not a compressed file */
 	rewind(s->file);
@@ -798,8 +793,7 @@ local void putLong (file, x)
 }
 
 /* ===========================================================================
-   Reads a long in LSB order from the given gz_stream. Sets z_err in case
-   of error.
+   Reads a long in LSB order from the given gz_stream. Sets 
 */
 local uLong getLong (s)
     gz_stream *s;
